@@ -5,7 +5,7 @@ umask 022
 echo Expect some cache has wrong version warnings if upgrading
 echo to version 1.7.x for the first time.
 
-. Version.mk
+. ./Version.mk
 
 PREFIX=
 
@@ -14,11 +14,11 @@ PREFIX=
 #	rm -f /etc/ld.so.cache
 #fi
 
-if [ ! -f /etc/ld.so.conf ] ; then
+if [ ! -f $PREFIX/etc/ld.so.conf ] ; then
 	echo Creating new /etc/ld.so.conf
 	for dir in /usr/local/lib /usr/X11R6/lib /usr/X386/lib /usr/openwin/lib /lib/elf ; do
-		if [ -d $dir ] ; then
-			echo $dir >> /etc/ld.so.conf
+		if [ -d $PREFIX$dir ] ; then
+			echo $dir >> $PREFIX/etc/ld.so.conf
 		fi
 	done
 fi
@@ -29,12 +29,12 @@ if [ -f ld-so/ld.so ] ; then
 	mv -f $PREFIX/lib/ld.so.$VERSION $PREFIX/lib/ld.so
 	ln -f $PREFIX/lib/ld.so $PREFIX/lib/ld.so.$VERSION
 
-	echo Installing libldso.a
-	if [ -d $PREFIX/usr/i486-linuxaout/lib ] ; then
-		install -c -m 644 ld-so/libldso.a $PREFIX/usr/i486-linuxaout/lib
-	else
-		install -c -m 644 ld-so/libldso.a $PREFIX/usr/lib
-	fi
+#	echo Installing libldso.a
+#	if [ -d $PREFIX/usr/i486-linuxaout/lib ] ; then
+#		install -c -m 644 ld-so/libldso.a $PREFIX/usr/i486-linuxaout/lib
+#	else
+#		install -c -m 644 ld-so/libldso.a $PREFIX/usr/lib
+#	fi
 else
 	echo Not installing a.out support
 fi
@@ -49,7 +49,9 @@ if [ -f d-link/ld-linux.so ] ; then
 	fi
 
 	echo Installing libdl.so
+	install -c -m 644 d-link/libdl/dlfcn.h $PREFIX/usr/include/dlfcn.h
 	install -c d-link/libdl/libdl.so $PREFIX/lib/libdl.so.$VERSION
+	ln -sf libdl.so.$VERSION $PREFIX/lib/libdl.so
 else
 	echo Not installing ELF support
 fi
