@@ -182,11 +182,17 @@ int main(int argc, char **argv, char **envp)
 	else
 	{
 	    /* then wait for it to complete */
-	    if (waitpid(pid, NULL, 0) != pid)
+	    int status;
+	    if (waitpid(pid, &status, 0) != pid)
 	    {
 	        fprintf(stderr, "%s: error waiting for %s (%s)\n", argv[0], 
 			argv[i], strerror(errno));
 	    }
+	    else if (WIFSIGNALED(status))
+	    {
+	        fprintf(stderr, "%s: %s exited with signal %d\n", argv[0], 
+			argv[i], WTERMSIG(status));
+	    }
 	}
     }
 
